{% extends "!layout.html" %}


{% block rootrellink %}
        <li><a href="{{ pathto('index') }}">pyregion documentation</a>|&nbsp;</li>
{% endblock %}


{% block relbar1 %}

{{ super() }}
{% endblock %}

{# put the sidebar before the body #}

{% block sidebar1 %}{{ sidebar() }}{% endblock %}
{% block sidebar2 %}{% endblock %}

