# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2021-05-21 13:05:24 UTC
from __future__ import unicode_literals
import datetime

version = "2.0.10"
githash = "fd80be7cf8698e2350a919ef7fc89871db0ba580"


major = 2
minor = 0
bugfix = 10

release = True
timestamp = datetime.datetime(2021, 5, 21, 13, 5, 24)
debug = False

astropy_helpers_version = ""

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
